@@ -1,13 +1,15 @@
 test_that("attributes and classes are kept", {
   skip_on_cran()
-  cdm <- mockPatientProfiles(con = connection(), writeSchema = writeSchema())
+  cdm <- mockPatientProfiles(source = "local") |>
+    copyCdm()
 
   oldCohort <- cdm$cohort1
-  newCohort <- cdm$cohort1 |> addDemographics()
+  newCohort <- cdm$cohort1 |>
+    addDemographics()
 
   expect_true(length(attributes(newCohort)) == length(attributes(oldCohort)))
   for (i in names(attributes(newCohort))) {
-    if (i != "tbl_name") {
+    if (i %in% c("class", "tbl_source", "cohort_set", "cohort_attrition", "cohort_codelist", "cdm_reference")) {
       x <- attr(newCohort, i)
       y <- attr(oldCohort, i)
       if (i == "class") {
@@ -25,7 +27,7 @@ test_that("attributes and classes are kept", {
 
   expect_true(length(attributes(newCohort)) == length(attributes(oldCohort)))
   for (i in names(attributes(newCohort))) {
-    if (i != "tbl_name") {
+    if (i %in% c("class", "tbl_source", "cohort_set", "cohort_attrition", "cohort_codelist", "cdm_reference")) {
       x <- attr(newCohort, i)
       y <- attr(oldCohort, i)
       if (i == "class") {
@@ -36,5 +38,5 @@ test_that("attributes and classes are kept", {
     }
   }
 
-  mockDisconnect(cdm = cdm)
+  dropCreatedTables(cdm = cdm)
 })
